-- Boudicca_Andraste
-- Author: FramedArchitecture
-- DateCreated: 6/2014
--------------------------------------------------------------------
include("UA_Functions.lua")
--------------------------------------------------------------------
local remove = table.remove
local insert = table.insert
local random = math.random
local boudiccaID = -1
local boudiccaTeamID = -1
local rageID = GameInfo.UnitPromotions["PROMOTION_FA_BOUDICCA"].ID
local rageChance = GameInfo.UnitPromotions[rageID].EnrageChance
local rageTurns = GameInfo.UnitPromotions[rageID].EnrageTurns
--------------------------------------------------------------------
function OnPlayerDoTurn(playerID)
	if playerID ~= boudiccaID then return end
	UpdateRageUnits();
end
--------------------------------------------------------------------
function OnCombatEnd(playerID, unitID, damage, finalDamage, maxHP)
	if playerID ~= boudiccaID then return end
	if finalDamage >= maxHP then return end

	local unit = Players[playerID]:GetUnitByID(unitID);
	if unit and IsLand(unit) then
		if unit:IsHasPromotion(rageID) then return end
		if random(1, 100) <= rageChance then
			local t = GetRageUnits()
			insert(t, {unit = unitID, turn = (Game.GetGameTurn() + rageTurns)})
			SaveRageUnits(t);

			unit:SetMoves(unit:MaxMoves())
			unit:SetHasPromotion(rageID, true)
		end
	end
end
--------------------------------------------------------------------
function OnWarStateChanged(teamID, otherteamID, bWar)
	if bWar and (teamID == boudiccaTeamID) then
		DoWarDivination(teamID, otherteamID);
	end
end
--------------------------------------------------------------------
function UpdateRageUnits()
	local t = GetRageUnits()
	if #t > 0 then
		local player = Players[boudiccaID]
		local c_turn = Game.GetGameTurn();
		local bSave = false

		for i,v in ipairs(t) do
			if v.turn <= c_turn then
				local unit = player:GetUnitByID(v.unit)
				if unit then
					unit:SetHasPromotion(rageID, false)
				end
				remove(t,i)
				bSave = true
			end
		end
		if bSave then
			SaveRageUnits(t)
		end
	end
end
--------------------------------------------------------------------
function DoWarDivination(teamID, otherTeamID)

	Events.ClearHexHighlights();

	local playerIDs = GetPlayerIDsFromTeamID(otherTeamID)
	for i in pairs(playerIDs) do
		local player = Players[i]
		for unit in player:Units() do
			if unit then
				local plot = unit:GetPlot()
				RevealPlotAndAdjacent(plot, teamID);
				EventPlotHighlight(plot);
			end
		end
		for city in player:Cities() do
			local plot = city:Plot()
			RevealPlotAndAdjacent(plot, teamID);
			EventPlotHighlight(plot);
		end
	end
	Game.UpdateFOW(true);
	UI.RequestMinimapBroadcast();
end
--------------------------------------------------------------------
function IsLand(unit)
	return unit:GetDomainType() == DomainTypes.DOMAIN_LAND
end
--------------------------------------------------------------------
function SaveRageUnits(t)
	SetPersistentTable("g_RageUnits", t);
end
--------------------------------------------------------------------
function GetRageUnits()
	return GetPersistentTable("g_RageUnits");
end
--------------------------------------------------------------------
function Init()
	for i = 0, GameDefines.MAX_MAJOR_CIVS - 1, 1 do
		local player = Players[i]
		if player and (GetTraitType(player) == "TRAIT_FA_BOUDICCA") then
			boudiccaID = i
			boudiccaTeamID = player:GetTeam()
			
			GameEvents.PlayerDoTurn.Add(OnPlayerDoTurn)
			Events.EndCombatSim.Add( OnCombatEnd )
			Events.WarStateChanged.Add(OnWarStateChanged)

			print("Boudicca_Andraste loaded")
			break;
		end
	end
end
--------------------------------------------------------------------
Init();

