-- Isabella_Reconquista
-- Author: FramedArchitecture
-- DateCreated: 6/2014
--------------------------------------------------------------------
include("UA_Functions.lua")
--------------------------------------------------------------------
local insert = table.insert
local isabellaID = -1
local isabellaTeamID = -1
local pantheonID = ReligionTypes.RELIGION_PANTHEON
--------------------------------------------------------------------
function OnCityCaptureComplete(oldOwnerID, bIsCapital, x, y, newOwnerID, pop, bConquest)
	if newOwnerID ~= isabellaID then return end
	if not bConquest then return end

	local player = Players[newOwnerID]
	
	local faith = GetTraitInfo(player).FaithOnConquest
	if faith > 0 then 
		player:ChangeFaith(pop * faith)

		local religionID = GetPlayerReligion(player)
		if religionID then 
			local city = Map.GetPlot(x, y):GetPlotCity();
			city:AdoptReligionFully(religionID);
		end
	end
end
--------------------------------------------------------------------
function OnTeamTechResearched(teamID, techID)
	if teamID ~= isabellaTeamID then return end
	local player = Players[isabellaID]
	if techID == GameInfoTypes[GetTraitInfo(player).TechRevealsCoasts] then
		RevealCoastalLands(teamID)
		--notification
		if player:IsHuman() then
			local heading = Locale.ConvertTextKey("TXT_KEY_FA_ISABELLA_DISCOVERY");
			local text = Locale.ConvertTextKey("TXT_KEY_FA_ISABELLA_DISCOVERY_TEXT");
			player:AddNotification(NotificationTypes.NOTIFICATION_GENERIC, text, heading, -1, -1);
		end
	end
end
--------------------------------------------------------------------
function GetPlayerReligion(player)
	if player:GetReligionCreatedByPlayer() > pantheonID then 
		return player:GetReligionCreatedByPlayer()
	else
		for row in GameInfo.Religions() do
			local religionID = row.ID
			if (religionID > pantheonID) and player:HasReligionInMostCities(religionID) then
				return religionID
			end
		end
	end
	return nil;
end
--------------------------------------------------------------------
function RevealCoastalLands(teamID)
	for i = 0, Map.GetNumPlots() - 1, 1 do
		local plot = Map.GetPlotByIndex( i );
		if plot:IsWater() and not plot:IsLake() then
			if plot:IsAdjacentToLand() then
				RevealPlotAndAdjacent(plot, teamID)
			end
		end
	end
end
--------------------------------------------------------------------
function Init()
	for i = 0, GameDefines.MAX_MAJOR_CIVS - 1, 1 do
		local player = Players[i]
		if player and (GetTraitType(player) == "TRAIT_FA_ISABELLA") then
			isabellaID = i
			isabellaTeamID = player:GetTeam()

			if IsPlayerHasTech(player, GetTraitInfo(player).TechRevealsCoasts) then
				RevealCoastalLands(isabellaTeamID)
			end

			GameEvents.CityCaptureComplete.Add( OnCityCaptureComplete )
			GameEvents.TeamTechResearched.Add( OnTeamTechResearched )

			print("Isabella_Reconquista loaded")
			break;
		end
	end
end
--------------------------------------------------------------------
Init();
