-- Montezuma_Sacrifice
-- Author: FramedArchitecture
-- DateCreated: 6/2014
--------------------------------------------------------------------
include("UA_Functions.lua")
--------------------------------------------------------------------
local bBNW = g_IsBNW
local random = math.random
local round = math.floor
local montezumaID = -1
local montezumaTeamID = -1
local maxCulturePerTurn = 0
local slaveID = GameInfo.Units["UNIT_FA_MONTEZUMA"].ID
local slaverID = GameInfo.UnitPromotions["PROMOTION_FA_MONTEZUMA"].ID
local enslaveChance = GameInfo.UnitPromotions[slaverID].EnslaveDefeatedChance
local bMontezumaAtWar = false
--------------------------------------------------------------------
function OnWarStateChanged(teamID, _, bWar)
	if (teamID == montezumaTeamID) and (bWar ~= bMontezumaAtWar) then
		bMontezumaAtWar = (Teams[montezumaTeamID]:GetAtWarCount(true) > 0)
		UpdateFlowerWar()
	end
end
--------------------------------------------------------------------
function UpdateFlowerWar()
	Players[montezumaID]:SetHasPolicy(GameInfoTypes.POLICY_TRAIT_FA_MONTEZUMA_WAR, bMontezumaAtWar)
end
--------------------------------------------------------------------
function OnCombatEnd(playerID, unitID, damage, finalDamage, maxHP, dPlayerID, dUnitID, dDamage, dFinalDamage, dMaxHP)
	if playerID ~= montezumaID then return end
	
	local player = Players[playerID]
	local unit = player:GetUnitByID(unitID)
	local dUnit = Players[dPlayerID]:GetUnitByID(dUnitID)

	if unit and unit:IsHasPromotion(slaverID) then
		if not dUnit and dFinalDamage >= dMaxHP then
			if random(1, 100) <= enslaveChance then
				local slave = player:InitUnit(slaveID, unit:GetX(), unit:GetY())
				slave:SetHasPromotion(slaverID, false)
				slave:JumpToNearestValidPlot();
			end
		end
	end
end
--------------------------------------------------------------------
function OnCanSaveUnit(playerID, unitID)
	if playerID ~= montezumaID then return false end

	local player = Players[playerID]
	local unit = player:GetUnitByID(unitID);
	if unit:GetUnitType() == slaveID then
		local city = unit:GetPlot():GetPlotCity()
		if city then
			if random(1, 100) <= (2 * enslaveChance) then
				city:SetPopulation(round(city:GetPopulation() + 1), true)
				--notification
				if player:IsHuman() then
					local heading = Locale.ConvertTextKey("TXT_KEY_FA_MONTEZUMA_SACRIFICE");
					local text = Locale.ConvertTextKey("TXT_KEY_FA_MONTEZUMA_SACRIFICE_TEXT", city:GetName());
					player:AddNotification(NotificationTypes.NOTIFICATION_GENERIC, text, heading, -1, -1);
				end
			end
		end
	end

    return false;
end
--------------------------------------------------------------------
function Init()
	for i = 0, GameDefines.MAX_MAJOR_CIVS - 1, 1 do
		local player = Players[i]
		if player and (GetTraitType(player) == "TRAIT_FA_MONTEZUMA") then
			montezumaID = i
			montezumaTeamID = player:GetTeam()
			bMontezumaAtWar = (Teams[montezumaTeamID]:GetAtWarCount(true) > 0)

			UpdateFlowerWar()
			Events.WarStateChanged.Add(OnWarStateChanged)
			Events.EndCombatSim.Add(OnCombatEnd)

			if bBNW then
				GameEvents.CanSaveUnit.Add( OnCanSaveUnit )
			end

			print("Montezuma_Sacrifice loaded")
			break;
		end
	end
end
--------------------------------------------------------------------
Init();
